*******
PROJECT
*******

Concise project description

.. toctree::
    :hidden:
    :maxdepth: 2

    Introduction <self>
    Getting Started <getting_started>
    User Guide <user_guide>
    Gallery <gallery>
    API <Reference_Manual>
    FAQ <FAQ>
    About <about>
